@@ -1,14 +1,14 @@
 """
 Type annotations for accessanalyzer service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_accessanalyzer/literals.html)
+[Open documentation](./literals.md)
 
 Usage::
 
     ```python
-    from mypy_boto3_accessanalyzer.literals import AccessPreviewStatus
+    from mypy_boto3_accessanalyzer.literals import AccessPreviewStatusReasonCodeType
 
-    data: AccessPreviewStatus = "COMPLETED"
+    data: AccessPreviewStatusReasonCodeType = "INTERNAL_ERROR"
     ```
 """
 import sys
@@ -20,17 +20,17 @@ else:
 
 
 __all__ = (
-    "AccessPreviewStatus",
-    "AccessPreviewStatusReasonCode",
-    "AclPermission",
-    "AnalyzerStatus",
-    "FindingChangeType",
-    "FindingSourceType",
-    "FindingStatus",
-    "FindingStatusUpdate",
-    "JobErrorCode",
-    "JobStatus",
-    "KmsGrantOperation",
+    "AccessPreviewStatusReasonCodeType",
+    "AccessPreviewStatusType",
+    "AclPermissionType",
+    "AnalyzerStatusType",
+    "FindingChangeTypeType",
+    "FindingSourceTypeType",
+    "FindingStatusType",
+    "FindingStatusUpdateType",
+    "JobErrorCodeType",
+    "JobStatusType",
+    "KmsGrantOperationType",
     "ListAccessPreviewFindingsPaginatorName",
     "ListAccessPreviewsPaginatorName",
     "ListAnalyzedResourcesPaginatorName",
@@ -38,33 +38,33 @@ __all__ = (
     "ListArchiveRulesPaginatorName",
     "ListFindingsPaginatorName",
     "ListPolicyGenerationsPaginatorName",
-    "Locale",
-    "OrderBy",
-    "PolicyType",
-    "ReasonCode",
-    "ResourceType",
+    "LocaleType",
+    "OrderByType",
+    "PolicyTypeType",
+    "ReasonCodeType",
+    "ResourceTypeType",
     "TypeType",
-    "ValidatePolicyFindingType",
+    "ValidatePolicyFindingTypeType",
     "ValidatePolicyPaginatorName",
 )
 
 
-AccessPreviewStatus = Literal["COMPLETED", "CREATING", "FAILED"]
-AccessPreviewStatusReasonCode = Literal["INTERNAL_ERROR", "INVALID_CONFIGURATION"]
-AclPermission = Literal["FULL_CONTROL", "READ", "READ_ACP", "WRITE", "WRITE_ACP"]
-AnalyzerStatus = Literal["ACTIVE", "CREATING", "DISABLED", "FAILED"]
-FindingChangeType = Literal["CHANGED", "NEW", "UNCHANGED"]
-FindingSourceType = Literal["BUCKET_ACL", "POLICY", "S3_ACCESS_POINT"]
-FindingStatus = Literal["ACTIVE", "ARCHIVED", "RESOLVED"]
-FindingStatusUpdate = Literal["ACTIVE", "ARCHIVED"]
-JobErrorCode = Literal[
+AccessPreviewStatusReasonCodeType = Literal["INTERNAL_ERROR", "INVALID_CONFIGURATION"]
+AccessPreviewStatusType = Literal["COMPLETED", "CREATING", "FAILED"]
+AclPermissionType = Literal["FULL_CONTROL", "READ", "READ_ACP", "WRITE", "WRITE_ACP"]
+AnalyzerStatusType = Literal["ACTIVE", "CREATING", "DISABLED", "FAILED"]
+FindingChangeTypeType = Literal["CHANGED", "NEW", "UNCHANGED"]
+FindingSourceTypeType = Literal["BUCKET_ACL", "POLICY", "S3_ACCESS_POINT"]
+FindingStatusType = Literal["ACTIVE", "ARCHIVED", "RESOLVED"]
+FindingStatusUpdateType = Literal["ACTIVE", "ARCHIVED"]
+JobErrorCodeType = Literal[
     "AUTHORIZATION_ERROR",
     "RESOURCE_NOT_FOUND_ERROR",
     "SERVICE_ERROR",
     "SERVICE_QUOTA_EXCEEDED_ERROR",
 ]
-JobStatus = Literal["CANCELED", "FAILED", "IN_PROGRESS", "SUCCEEDED"]
-KmsGrantOperation = Literal[
+JobStatusType = Literal["CANCELED", "FAILED", "IN_PROGRESS", "SUCCEEDED"]
+KmsGrantOperationType = Literal[
     "CreateGrant",
     "Decrypt",
     "DescribeKey",
@@ -87,16 +87,16 @@ ListAnalyzersPaginatorName = Literal["list_analyzers"]
 ListArchiveRulesPaginatorName = Literal["list_archive_rules"]
 ListFindingsPaginatorName = Literal["list_findings"]
 ListPolicyGenerationsPaginatorName = Literal["list_policy_generations"]
-Locale = Literal["DE", "EN", "ES", "FR", "IT", "JA", "KO", "PT_BR", "ZH_CN", "ZH_TW"]
-OrderBy = Literal["ASC", "DESC"]
-PolicyType = Literal["IDENTITY_POLICY", "RESOURCE_POLICY", "SERVICE_CONTROL_POLICY"]
-ReasonCode = Literal[
+LocaleType = Literal["DE", "EN", "ES", "FR", "IT", "JA", "KO", "PT_BR", "ZH_CN", "ZH_TW"]
+OrderByType = Literal["ASC", "DESC"]
+PolicyTypeType = Literal["IDENTITY_POLICY", "RESOURCE_POLICY", "SERVICE_CONTROL_POLICY"]
+ReasonCodeType = Literal[
     "AWS_SERVICE_ACCESS_DISABLED",
     "DELEGATED_ADMINISTRATOR_DEREGISTERED",
     "ORGANIZATION_DELETED",
     "SERVICE_LINKED_ROLE_CREATION_FAILED",
 ]
-ResourceType = Literal[
+ResourceTypeType = Literal[
     "AWS::IAM::Role",
     "AWS::KMS::Key",
     "AWS::Lambda::Function",
@@ -106,5 +106,5 @@ ResourceType = Literal[
     "AWS::SecretsManager::Secret",
 ]
 TypeType = Literal["ACCOUNT", "ORGANIZATION"]
-ValidatePolicyFindingType = Literal["ERROR", "SECURITY_WARNING", "SUGGESTION", "WARNING"]
+ValidatePolicyFindingTypeType = Literal["ERROR", "SECURITY_WARNING", "SUGGESTION", "WARNING"]
 ValidatePolicyPaginatorName = Literal["validate_policy"]
